@@ -1,5 +1,5 @@
 package DBIx::Perlish::Parse;
-# $Id: Parse.pm,v 1.57 2007/03/06 10:58:02 tobez Exp $
+# $Id: Parse.pm,v 1.60 2007/03/08 15:40:12 tobez Exp $
 use 5.008;
 use warnings;
 use strict;
@@ -459,6 +459,11 @@ sub parse_term
 		} else {
 			return "null";
 		}
+	} elsif (is_unop($op, "backtick")) {
+		my $fop = $op->first;
+		$fop = $fop->sibling while is_op($fop, "null");
+		my $sql = is_const($S, $fop);
+		return $sql if $sql;
 	} elsif (is_binop($op)) {
 		my $expr = parse_expr($S, $op);
 		return "($expr)";
@@ -572,12 +577,14 @@ sub try_parse_subselect
 		bailout $S, "empty array in not valid in \"<-\"" unless @$$ary;
 		$sql = join ",", ("?") x @$$ary;
 		@vals = @$$ary;
-	} elsif (is_unop($sub, "srefgen") &&
+	} elsif (is_listop($sub, "anonlist") or
+			 is_unop($sub, "srefgen") &&
 			 is_unop($sub->first, "null") &&
 			 is_listop($sub->first->first, "anonlist"))
 	{
 		my @what;
-		for my $v (get_all_children($sub->first->first)) {
+		my $alist = is_listop($sub, "anonlist") ? $sub : $sub->first->first;
+		for my $v (get_all_children($alist)) {
 			next if is_op($v, "pushmark");
 			if (my ($const,$sv) = is_const($S, $v)) {
 				if (($sv->isa("B::IV") && !$sv->isa("B::PVIV")) ||
@@ -652,7 +659,7 @@ sub parse_assign
 	}
 	bailout $S, "assignments are not understood in $S->{operation}'s query sub"
 		unless $S->{operation} eq "update";
-	if (is_unop($op->first, "srefgen")) {
+	if (is_unop($op->first, "srefgen") || is_listop($op->first, "anonhash")) {
 		parse_multi_assign($S, $op);
 	} else {
 		parse_simple_assign($S, $op);
@@ -757,9 +764,11 @@ sub parse_multi_assign
 	my ($S, $op) = @_;
 
 	my $hashop = $op->first;
-	want_unop($S, $hashop, "srefgen");
-	$hashop = $hashop->first;
-	$hashop = $hashop->first while is_unop($hashop, "null");
+	unless (is_listop($hashop, "anonhash")) {
+		want_unop($S, $hashop, "srefgen");
+		$hashop = $hashop->first;
+		$hashop = $hashop->first while is_unop($hashop, "null");
+	}
 	want_listop($S, $hashop, "anonhash");
 
 	my $saved_values = $S->{values};
@@ -961,10 +970,21 @@ sub parse_entersub
 
 sub parse_complex_regex
 {
-	my ( $S, $op) = @_;
+	my ($S, $op) = @_;
 
-	if ( is_unop( $op)) {
-		return parse_complex_regex( $S, $op-> first);
+	if (is_unop($op, "regcreset")) {
+		if (is_unop($op->first, "null")) {
+			my $rx = "";
+			my $rxop = $op->first->first;
+			while (!is_null($rxop)) {
+				$rx .= parse_complex_regex($S, $rxop)
+					unless is_op($rxop, "pushmark");
+				$rxop = $rxop->sibling;
+			}
+			return $rx;
+		} else {
+			return parse_complex_regex( $S, $op-> first);
+		}
 	} elsif ( is_binop( $op, 'concat')) {
 		$op = $op-> first;
 		return 
